@@ -13,6 +13,7 @@ import copy
 import collections
 import collections.abc
 import textwrap
+from urllib.parse import urlparse
 
 from datetime import datetime
 import itertools
@@ -109,6 +110,8 @@ def _parse_schema(schema, method):
     if 'enum' in schema:
         if 'example' in schema:
             return schema['example']
+        if 'default' in schema:
+            return schema['default']
         # we show the first one
         return schema['enum'][0]
 
@@ -165,6 +168,8 @@ def _parse_schema(schema, method):
 
     if 'example' in schema:
         return schema['example']
+    if 'default' in schema:
+        return schema['default']
     if (schema_type, schema.get('format')) in _TYPE_MAPPING:
         return _TYPE_MAPPING[(schema_type, schema.get('format'))]
 
@@ -318,7 +323,7 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
         yield ''
 
     if 'description' in properties:
-        for line in convert(properties['description']).splitlines():
+        for line in convert(properties['description']).strip().splitlines():
             yield '{indent}{line}'.format(**locals())
         yield ''
 
@@ -342,7 +347,8 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
                 if not desc[-1] == '.':
                     desc = desc + '.'
             if doc[1]:
-                if not doc[1].startswith(_("Object of")) and not doc[1].startswith(_("Array of")):
+                if not doc[1].startswith(str(_("Object of"))) and \
+                   not doc[1].startswith(str(_("Array of"))):
                     doc[1] = _("Object of type {}").format(doc[1])
                 if not doc[1][-1] == '.':
                     doc[1] = doc[1] + '.'
@@ -372,6 +378,9 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
             name=param['name'])
 
         desc = param.get('description', '')
+        if desc:
+            # in case the description uses markdown format
+            desc = convert(desc).strip()
         desc = get_desc(desc, param['schema'], indent)
         if desc:
             yield '{indent}{indent}{desc}'.format(**locals())
@@ -382,6 +391,9 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
             type=param['schema']['type'],
             name=param['name'])
         desc = param.get('description', '')
+        if desc:
+            # in case the description uses markdown format
+            desc = convert(desc).strip()
         desc = get_desc(desc, param['schema'], indent)
         if desc:
             yield '{indent}{indent}{desc}'.format(**locals())
@@ -392,12 +404,19 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
         example = param.get('example', example)
         if param.get('explode', False) and isinstance(example, list):
             for v in example:
+                if isinstance(v, bool):
+                    v = {True: 'true', False: 'false'}[v]
                 query_param_examples.append((param['name'], v))
         elif param.get('explode', False) and isinstance(example, dict):
             for k, v in example.items():
+                if isinstance(v, bool):
+                    v = {True: 'true', False: 'false'}[v]
                 query_param_examples.append((k, v))
         else:
-            query_param_examples.append((param['name'], example))
+            v = example
+            if isinstance(v, bool):
+                v = {True: 'true', False: 'false'}[v]
+            query_param_examples.append((param['name'], v))
 
     # print request content
     if render_request:
@@ -416,6 +435,9 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
                 # yield ''
     else:
         desc = properties.get('requestBody', {}).get('description', '')
+        if desc:
+            # in case the description uses markdown format
+            desc = convert(desc).strip()
         request_content = properties.get('requestBody', {}).get('content', {})
         if request_content and 'application/json' in request_content:
             schema = request_content['application/json'].get('schema', {})
@@ -427,6 +449,9 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
                 for prop, v in schema.get('properties', {}).items():
                     ptype = v.get('type', '')
                     desc = v.get('description', '')
+                    if desc:
+                        # in case the description uses markdown format
+                        desc = convert(desc).strip()
                     yield '{indent}:jsonparam {ptype} {prop}: {desc}'.format(**locals()).rstrip()
         else:
             if desc:
@@ -437,6 +462,9 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
     for param in filter(lambda p: p['in'] == 'header', parameters):
         yield indent + ':reqheader {name}:'.format(**param)
         desc = param.get('description', '')
+        if desc:
+            # in case the description uses markdown format
+            desc = convert(desc).strip()
         desc = get_desc(desc, param['schema'], indent)
         if desc:
             yield '{indent}{indent}{desc}'.format(**locals())
@@ -472,6 +500,9 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
         for headername, header in response.get('headers', {}).items():
             yield indent + ':resheader {name}:'.format(name=headername)
             desc = header.get('description', '')
+            if desc:
+                # in case the description uses markdown format
+                desc = convert(desc).strip()
             desc = get_desc(desc, header.get('schema', {}), indent)
             if desc:
                 yield '{indent}{indent}{desc}'.format(**locals())
@@ -484,16 +515,30 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
 
     # print response status codes
     for status, response in responses.items():
+        resheader_examples = {}
+        for headername, header in response.get('headers', {}).items():
+            ex = header.get('example', header.get('schema', {}).get('example', None))
+            if ex is None:
+                # try examples
+                ex = header.get('examples', header.get('schema', {}).get('examples', [None]))[0]
+            if ex:
+                resheader_examples[headername] = ex
         yield '{indent}:status {status}:'.format(**locals())
         content = response.get('content', {})
         if entities and content and 'application/json' in content:
             schema = content['application/json']['schema']
             desc = response.get('description', '')
+            if desc:
+                # in case the description uses markdown format
+                desc = convert(desc).strip()
             desc = get_desc(desc, schema, indent, deep=False)
             if desc:
                 yield '{indent}{indent}{desc}'.format(**locals())
         else:
             desc = response.get('description', '')
+            if desc:
+                # in case the description uses markdown format
+                desc = convert(desc).strip()
             if desc and desc[-1] != '.':
                 desc += '.'
             for line in convert(desc.splitlines()):
@@ -527,6 +572,16 @@ def _httpresource(endpoint, method, properties, convert, render_examples,
 
         # print response example
         for status, response in responses.items():
+            resheader_examples = {}
+            for headername, header in response.get('headers', {}).items():
+                ex = header.get('example', header.get('schema', {}).get('example', None))
+                if ex is None:
+                    # try examples
+                    ex = header.get('examples', header.get('schema', {}).get(
+                        'examples',
+                        [None]))[0]
+                if ex:
+                    resheader_examples[headername] = ex
             for line in _example(
                     response.get('content', {}),
                     status=status,
@@ -588,6 +643,14 @@ def openapihttpdomain(spec, **options):
             )
         paths = options['paths']
 
+    contextpath = ''
+    if 'contextpath' in options:
+        if 'servers' in spec:
+            h = spec['servers'][0]['url']
+            contextpath = urlparse(h).path
+            if contextpath and contextpath[-1] == '/':
+                contextpath = contextpath[:-1]
+
     # Check against regular expressions to be included
     if 'include' in options:
         for i in options['include']:
@@ -635,7 +698,7 @@ def openapihttpdomain(spec, **options):
                     continue
                 key = properties.get('tags', [''])[0]
                 groups.setdefault(key, []).append(_httpresource(
-                    endpoint,
+                    contextpath+endpoint,
                     method,
                     properties,
                     convert,
@@ -657,7 +720,7 @@ def openapihttpdomain(spec, **options):
                 if options.get('methods') and method not in options.get('methods'):
                     continue
                 generators.append(_httpresource(
-                    endpoint,
+                    contextpath+endpoint,
                     method,
                     properties,
                     convert,
