@@ -1,5 +1,7 @@
 
 import re
+from urllib.parse import urlparse
+
 from . import abc
 from .. import utils
 from docutils.parsers.rst import directives
@@ -10,6 +12,7 @@ class TocRenderer(abc.RestructuredTextRenderer):
     option_spec = {
         # nb columns
         "nb_columns": directives.positive_int,
+        "contextpath": directives.flag,     # use the server path as prefix in service URL
     }
 
     def __init__(self, state, options):
@@ -22,13 +25,21 @@ class TocRenderer(abc.RestructuredTextRenderer):
 
         utils.normalize_spec(spec, **self._options)
 
+        contextpath = ''
+        if 'contextpath' in self._options:
+            if 'servers' in spec:
+                h = spec['servers'][0]['url']
+                contextpath = urlparse(h).path
+                if contextpath and contextpath[-1] == '/':
+                    contextpath = contextpath[:-1]
+
         yield ""
         yield ".. hlist::"
         yield "    :columns: {}".format(self._options["nb_columns"])
         yield ""
 
         for path in spec["paths"].keys():
-            cpath = re.sub(r"[{}]", "", re.sub(r"[<>:/]", "-", path))
+            cpath = re.sub(r"[{}]", "", re.sub(r"[<>:/]", "-", contextpath+path))
             for verb, ope in spec["paths"][path].items():
                 yield "    - `{} <#{}>`_".format(
                     ope.get("operationId", verb + " " + path),
