@@ -1919,7 +1919,7 @@ class TestOpenApi3HttpDomain(object):
         ''').lstrip()
 
     def test_header_example(self):
-        renderer = renderers.HttpdomainOldRenderer(None, {'examples': True})
+        renderer = renderers.HttpdomainOldRenderer(None, {'examples': True, "contextpath": True})
         spec = yaml.safe_load(textwrap.dedent("""
         ---
         openapi: 3.0.0
@@ -1957,6 +1957,13 @@ class TestOpenApi3HttpDomain(object):
                       schema:
                         type: string
                       example: "MD5=thvDyvhfIqlvFe+A9MYgxAfm1q5="
+                400:
+                  description: Error
+                  content:
+                    application/json:
+                      schema:
+                        type: string
+                      example: ERROR
         """))
 
         text = '\n'.join(renderer.render_restructuredtext_markup(spec))
@@ -1998,6 +2005,18 @@ class TestOpenApi3HttpDomain(object):
 
                      RESPONSE
 
+               :status 400:
+                  Error.
+
+                  **Example response:**
+
+                  .. sourcecode:: http
+
+                     HTTP/1.1 400 Bad Request
+                     Content-Type: application/json
+
+                     ERROR
+
         ''').lstrip()
 
         renderer = renderers.HttpdomainOldRenderer(
@@ -2023,6 +2042,8 @@ class TestOpenApi3HttpDomain(object):
                   response header.
                :status 200:
                   Success.
+               :status 400:
+                  Error.
 
                **Example request:**
 
@@ -2046,6 +2067,16 @@ class TestOpenApi3HttpDomain(object):
 
                   RESPONSE
 
+
+               **Example response:**
+
+               .. sourcecode:: http
+
+                  HTTP/1.1 400 Bad Request
+                  Content-Type: application/json
+
+                  ERROR
+
         ''').lstrip()
 
     def test_entities(self):
@@ -2053,6 +2084,8 @@ class TestOpenApi3HttpDomain(object):
         spec = yaml.safe_load(textwrap.dedent("""
         ---
         openapi: 3.0.0
+        servers:
+        - url: https://test.org/context
         paths:
           /resources:
             post:
@@ -2275,6 +2308,192 @@ class TestOpenApi3HttpDomain(object):
                 Object of type string.
         ''').lstrip()
 
+    def test_contextpath(self):
+        spec = yaml.safe_load(textwrap.dedent("""
+        ---
+        openapi: 3.0.0
+        servers:
+        - url: https://test.org/context
+        paths:
+          /resources:
+            get:
+              summary: Summary
+              responses:
+                200:
+                  description: Success
+                  content:
+                    application/json:
+                      schema:
+                        type: string
+                      example: RESPONSE
+        """))
+
+        renderer = renderers.HttpdomainOldRenderer(None, {'contextpath': True, 'examples': True})
+        text = '\n'.join(renderer.render_restructuredtext_markup(spec))
+        assert text == textwrap.dedent('''
+          .. http:get:: /context/resources
+             :synopsis: Summary
+
+             **Summary**
+
+
+             **Example request:**
+
+             .. sourcecode:: http
+
+                GET /context/resources HTTP/1.1
+                Host: example.com
+
+             :status 200:
+                Success.
+
+                **Example response:**
+
+                .. sourcecode:: http
+
+                   HTTP/1.1 200 OK
+                   Content-Type: application/json
+
+                   RESPONSE
+
+                 ''').lstrip()
+
+        renderer = renderers.HttpdomainOldRenderer(None, {
+                'contextpath': True,
+                'examples': True,
+                'group': True
+            })
+        text = '\n'.join(renderer.render_restructuredtext_markup(spec))
+        assert text == textwrap.dedent('''
+          default
+          =======
+
+          .. http:get:: /context/resources
+             :synopsis: Summary
+
+             **Summary**
+
+
+             **Example request:**
+
+             .. sourcecode:: http
+
+                GET /context/resources HTTP/1.1
+                Host: example.com
+
+             :status 200:
+                Success.
+
+                **Example response:**
+
+                .. sourcecode:: http
+
+                   HTTP/1.1 200 OK
+                   Content-Type: application/json
+
+                   RESPONSE
+
+                 ''').lstrip()
+
+    def test_bool_param_in_query(self):
+        renderer = renderers.HttpdomainOldRenderer(None, {'examples': True})
+        spec = yaml.safe_load(textwrap.dedent("""
+        ---
+        openapi: 3.0.0
+        paths:
+          /resources:
+            get:
+              summary: Summary
+              description: test service
+              parameters:
+                - name: myparam
+                  in: query
+                  description: test param
+                  schema:
+                    type: boolean
+                    default: false
+              responses:
+                200:
+                  description: Success
+        """))
+
+        text = '\n'.join(renderer.render_restructuredtext_markup(spec))
+        assert text == textwrap.dedent('''
+            .. http:get:: /resources
+               :synopsis: Summary
+
+               **Summary**
+
+               test service
+
+               :query boolean myparam:
+                  test param.
+                  Default: ``false``.
+
+               **Example request:**
+
+               .. sourcecode:: http
+
+                  GET /resources?myparam=false HTTP/1.1
+                  Host: example.com
+
+               :status 200:
+                  Success.
+        ''').lstrip()
+
+    def test_markdown(self):
+        renderer = renderers.HttpdomainOldRenderer(None, {'format': 'markdown', 'examples': True})
+        spec = yaml.safe_load(textwrap.dedent("""
+        ---
+        openapi: 3.0.0
+        paths:
+          /resources/{opt}:
+            post:
+              summary: Summary
+              description: test service in __bold__
+              parameters:
+                - name: opt
+                  in: path
+                  description: test param in _italic_
+                  schema:
+                    type: string
+                - name: myparam
+                  in: query
+                  description: test param in _italic_
+                  schema:
+                    type: boolean
+                    default: false
+                - name: myheader
+                  in: header
+                  description: test param in _italic_
+                  schema:
+                    type: boolean
+                    default: false
+              responses:
+                200:
+                  description: Success
+        """))
+        text = '\n'.join(renderer.render_restructuredtext_markup(spec))
+        assert text == textwrap.dedent('''
+            .. http:post:: /resources/{opt}
+               :synopsis: Summary
+
+               **Summary**
+
+               test service in **bold**
+
+               :param string opt:
+                  test param in *italic*.
+               :query boolean myparam:
+                  test param in *italic*.
+                  Default: ``false``.
+               :reqheader myheader:
+                  test param in *italic*.
+                  Default: ``false``.
+               :status 200:
+                  Success.
+        ''').lstrip()
+
 
 class TestResolveRefs(object):
 
@@ -2319,7 +2538,7 @@ class TestResolveRefs(object):
         }
 
     def test_relative_ref_resolving_on_fs(self):
-        baseuri = 'file://%s' % os.path.abspath(__file__).replace('\\', '/').replace('C:', '')
+        baseuri = 'file:///%s' % os.path.abspath(__file__).replace('\\', '/')
 
         data = {
             'bar': {
